@@ -29,9 +29,12 @@
 #include "gom-gdata-miner.h"
 
 #define MINER_IDENTIFIER "gd:gdata:miner:86ec9bc9-c242-427f-aa19-77b5a2c9b6f0"
-#define STARRED_CATEGORY_TERM "http://schemas.google.com/g/2005/labels#starred"
 #define PARENT_LINK_REL "http://schemas.google.com/docs/2007#parent"
 
+/* used by applications to identify the source of an entry */
+#define PREFIX_DRIVE "google:drive:"
+#define PREFIX_PICASAWEB "google:picasaweb:"
+
 G_DEFINE_TYPE (GomGDataMiner, gom_gdata_miner, GOM_TYPE_MINER)
 
 static gchar *
@@ -81,10 +84,15 @@ account_miner_job_process_entry (GomAccountMinerJob *job,
       GDataLink *link;
 
       link = gdata_entry_look_up_link (entry, GDATA_LINK_SELF);
-      identifier = g_strdup_printf ("gd:collection:%s", gdata_link_get_uri (link));
+      identifier = g_strdup_printf ("gd:collection:%s%s", PREFIX_DRIVE, gdata_link_get_uri (link));
     }
   else
-    identifier = g_strdup (gdata_entry_get_id (entry));
+    {
+      const gchar *id;
+
+      id = gdata_entry_get_id (entry);
+      identifier = g_strdup_printf ("%s%s", PREFIX_DRIVE, id);
+    }
 
   /* remove from the list of the previous resources */
   g_hash_table_remove (job->previous_resources, identifier);
@@ -168,7 +176,7 @@ account_miner_job_process_entry (GomAccountMinerJob *job,
 
       parent = l->data;
       parent_resource_id =
-        g_strdup_printf ("gd:collection:%s", gdata_link_get_uri (parent));
+        g_strdup_printf ("gd:collection:%s%s", PREFIX_DRIVE, gdata_link_get_uri (parent));
 
       parent_resource_urn = gom_tracker_sparql_connection_ensure_resource
         (job->connection, job->cancellable, error,
@@ -195,7 +203,7 @@ account_miner_job_process_entry (GomAccountMinerJob *job,
   for (l = categories; l != NULL; l = l->next)
     {
       category = l->data;
-      if (g_strcmp0 (gdata_category_get_term (category), STARRED_CATEGORY_TERM) == 0)
+      if (g_strcmp0 (gdata_category_get_term (category), GDATA_CATEGORY_SCHEMA_LABELS_STARRED) == 0)
         {
           starred = TRUE;
           break;
@@ -373,7 +381,7 @@ account_miner_job_process_photo (GomAccountMinerJob *job,
         }
     }
 
-  identifier = g_strdup_printf ("google:picasaweb:%s", id);
+  identifier = g_strdup_printf ("%s%s", PREFIX_PICASAWEB, id);
 
   /* remove from the list of the previous resources */
   g_hash_table_remove (job->previous_resources, identifier);
@@ -651,7 +659,7 @@ account_miner_job_process_album (GomAccountMinerJob *job,
   const gchar *alternate_uri;
 
   album_id = gdata_entry_get_id (GDATA_ENTRY (album));
-  identifier = g_strdup_printf ("photos:collection:google:picasaweb:%s", album_id);
+  identifier = g_strdup_printf ("photos:collection:%s%s", PREFIX_PICASAWEB, album_id);
 
   /* remove from the list of the previous resources */
   g_hash_table_remove (job->previous_resources, identifier);
@@ -924,7 +932,7 @@ gom_gdata_miner_class_init (GomGDataMinerClass *klass)
 
   miner_class->goa_provider_type = "google";
   miner_class->miner_identifier = MINER_IDENTIFIER;
-  miner_class->version = 4;
+  miner_class->version = 5;
 
   miner_class->create_services = create_services;
   miner_class->query = query_gdata;
